@@ -1,10 +1,10 @@
 package Apache2::AuthCookie::Base;
-$Apache2::AuthCookie::Base::VERSION = '3.23';
+$Apache2::AuthCookie::Base::VERSION = '3.25';
 use strict;
 use mod_perl2 '1.99022';
 use Carp;
 
-use Apache::AuthCookie::Util;
+use Apache::AuthCookie::Util qw(is_blank);
 use Apache2::AuthCookie::Params;
 use Apache2::RequestRec;
 use Apache2::RequestUtil;
@@ -12,7 +12,6 @@ use Apache2::Log;
 use Apache2::Access;
 use Apache2::Response;
 use Apache2::Util;
-use Apache::AuthCookie::Autobox;
 use APR::Table;
 use Apache2::Const qw(:common M_GET HTTP_FORBIDDEN HTTP_MOVED_TEMPORARILY HTTP_OK);
 
@@ -20,16 +19,16 @@ sub recognize_user {
     my ($self, $r) = @_;
 
     # only check if user is not already set
-    return DECLINED unless $r->user->is_blank;
+    return DECLINED unless is_blank($r->user);
 
     my $debug = $r->dir_config("AuthCookieDebug") || 0;
 
     my $auth_type = $r->auth_type;
     my $auth_name = $r->auth_name;
 
-    return DECLINED if $auth_type->is_blank or $auth_name->is_blank;
+    return DECLINED if is_blank($auth_type) or is_blank($auth_name);
 
-    return DECLINED if $r->headers_in->get('Cookie')->is_blank;
+    return DECLINED if is_blank($r->headers_in->get('Cookie'));
 
     my $cookie = $self->key($r);
     my $cookie_name = $self->cookie_name($r);
@@ -37,11 +36,11 @@ sub recognize_user {
     $r->server->log_error("cookie $cookie_name is $cookie")
         if $debug >= 2;
 
-    return DECLINED if $cookie->is_blank;
+    return DECLINED if is_blank($cookie);
 
     my ($user,@args) = $auth_type->authen_ses_key($r, $cookie);
 
-    if (!$user->is_blank and scalar @args == 0) {
+    if (!is_blank($user) and scalar @args == 0) {
         $r->server->log_error("user is $user") if $debug >= 2;
 
         # send cookie with update expires timestamp if session timeout is on
@@ -55,7 +54,7 @@ sub recognize_user {
         return $auth_type->custom_errors($r, $user, @args);
     }
 
-    return $user->is_blank ? DECLINED : OK;
+    return is_blank($user) ? DECLINED : OK;
 }
 
 sub cookie_name {
@@ -228,12 +227,14 @@ sub authenticate {
     $r->server->log_error("authenticate() entry") if ($debug >= 3);
     $r->server->log_error("auth_type " . $auth_type) if ($debug >= 3);
 
-    unless ($r->is_initial_req) {
-        if (defined $r->prev) {
-            # we are in a subrequest.  Just copy user from previous request.
-            $r->user( $r->prev->user );
+    if (my $prev = ($r->prev || $r->main)) {
+        # we are in a subrequest or internal redirect.  Just copy user from the
+        # previous or main request if its is present
+        if (defined $prev->user) {
+            $r->server->log_error('authenticate() is in a subrequest or internal redirect.') if $debug >= 3;
+            $r->user( $prev->user );
+            return OK;
         }
-        return OK;
     }
 
     if ($debug >= 3) {
@@ -266,7 +267,7 @@ sub authenticate {
     if ($ses_key_cookie) {
         my ($auth_user, @args) = $auth_type->authen_ses_key($r, $ses_key_cookie);
 
-        if (!$auth_user->is_blank and scalar @args == 0) {
+        if (!is_blank($auth_user) and scalar @args == 0) {
             # We have a valid session key, so we return with an OK value.
             # Tell the rest of Apache what the authentication method and
             # user is.
@@ -450,7 +451,7 @@ Apache2::AuthCookie::Base
 
 =head1 VERSION
 
-version 3.23
+version 3.25
 
 =head1 SOURCE
 
